@@ -71,7 +71,7 @@
                                       (variables rest ...))))))
     (variables %localstatedir %storedir %sysconfdir %system)))
 
-(define* (make-config.scm #:key zlib gzip xz bzip2
+(define* (make-config.scm #:key gzip xz bzip2
                           (package-name "GNU Guix")
                           (package-version "0")
                           (bug-report-address "bug-guix@gnu.org")
@@ -133,11 +133,7 @@
                      (define %bzip2
                        #+(and bzip2 (file-append bzip2 "/bin/bzip2")))
                      (define %xz
-                       #+(and xz (file-append xz "/bin/xz")))
-
-                     (define %libz
-                       #+(and zlib
-                              (file-append zlib "/lib/libz")))))))
+                       #+(and xz (file-append xz "/bin/xz")))))))
 
 
 ;;;
@@ -384,11 +380,11 @@ interface (FFI) of Guile.")
                 #:key verbose? (version (date-version-string)) system
                 (pull-version 0)
 
-                ;; For the standalone Guix, default to Guile 2.2.  For old
+                ;; For the standalone Guix, default to Guile 3.0.  For old
                 ;; versions of 'guix pull' (pre-0.15.0), we have to use the
                 ;; same Guile as the current one.
                 (guile-version (if (> pull-version 0)
-                                   "2.2"
+                                   "3.0"
                                    (effective-version)))
 
                 #:allow-other-keys
