@@ -1,5 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2014, 2015, 2016 Eric Bavier <bavier@member.fsf.org>
+;;; Copyright © 2014, 2015, 2016, 2018 Eric Bavier <bavier@member.fsf.org>
+;;; Copyright © 2016, 2017 Efraim Flashner <efraim@flashner.co.il>
+;;; Copyright © 2018, 2019, 2020 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -28,27 +30,26 @@
 (define-public ccache
   (package
     (name "ccache")
-    (version "3.2.4")
+    (version "3.7.12")
     (source
      (origin
-      (method url-fetch)
-      (uri (string-append "https://www.samba.org/ftp/ccache/ccache-"
-                          version ".tar.xz"))
-      (sha256
-       (base32
-        "0pga3hvd80f2p7mz88jmmbwzxh4vn5ihyjx5f6na8y2fclzsjg8w"))))
+       (method url-fetch)
+       (uri (string-append "https://github.com/ccache/ccache/releases/download/v"
+                           version "/ccache-" version ".tar.xz"))
+       (sha256
+        (base32 "005liq8csgxdn7m9hj2ah07hishww855p8sc96y1hrnwc21lwbx0"))))
     (build-system gnu-build-system)
-    (native-inputs `(("perl" ,perl)))   ;for test.sh
+    (native-inputs `(("perl" ,perl)     ; for test/run
+                     ("which" ,(@ (gnu packages base) which))))
     (inputs `(("zlib" ,zlib)))
     (arguments
-     '(#:phases (alist-cons-before
-                 'check 'setup-tests
-                 (lambda _
-                   (substitute* '("test/test_hashutil.c" "test.sh")
-                     (("#!/bin/sh") (string-append "#!" (which "sh"))))
-                   #t)
-                 %standard-phases)))
-    (home-page "https://ccache.samba.org/")
+     '(#:phases (modify-phases %standard-phases
+                  (add-before 'check 'setup-tests
+                    (lambda _
+                      (substitute* '("unittest/test_hashutil.c" "test/suites/base.bash")
+                        (("#!/bin/sh") (string-append "#!" (which "sh"))))
+                      #t)))))
+    (home-page "https://ccache.dev/")
     (synopsis "Compiler cache")
     (description
      "Ccache is a compiler cache.  It speeds up recompilation by caching
