@@ -4,7 +4,7 @@
 ;;; Copyright © 2016 Ricardo Wurmus <rekado@elephly.net>
 ;;; Copyright © 2017 nee <nee.git@cock.li>
 ;;; Copyright © 2018, 2019 Tobias Geerinckx-Rice <me@tobias.gr>
-;;; Copyright © 2018 ng0 <ng0@n0.is>
+;;; Copyright © 2018 Nikita <nikita@n0.is>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -33,16 +33,16 @@
 (define-public elixir
   (package
     (name "elixir")
-    (version "1.10.2")
+    (version "1.10.4")
     (source
      (origin
        (method git-fetch)
        (uri (git-reference
-             (url "https://github.com/elixir-lang/elixir.git")
+             (url "https://github.com/elixir-lang/elixir")
              (commit (string-append "v" version))))
        (file-name (git-file-name name version))
        (sha256
-        (base32 "04yi1hljq7ii9flh6pmb5411z7q1bdq9f9sq8323k9hm1f5jwkx6"))
+        (base32 "16j4rmm3ix088fvxhvyjqf1hnfg7wiwa87gml3b2mrwirdycbinv"))
        (patches (search-patches "elixir-path-length.patch"))))
     (build-system gnu-build-system)
     (arguments
