@@ -1,6 +1,9 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2014, 2015 Mark H Weaver <mhw@netris.org>
+;;; Copyright © 2016, 2017 Efraim Flashner <efraim@flashner.co.il>
+;;; Copyright © 2018 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2018 Efraim Flashner <efraim@flashner.co.il>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -26,27 +29,28 @@
 
 (define-public file
   (package
-   (name "file")
-    (version "5.22")
+    (name "file")
+    (version "5.38")
     (source (origin
               (method url-fetch)
               (uri (string-append "ftp://ftp.astron.com/pub/file/file-"
                                   version ".tar.gz"))
               (sha256
                (base32
-                "02zw14hw3gqlw91w2f2snbirvyrp7r83irvnnkjcb25q9kjaiqy4"))))
+                "0d7s376b4xqymnrsjxi3nsv3f5v89pzfspzml2pcajdk5by2yg2r"))))
    (build-system gnu-build-system)
 
    ;; When cross-compiling, this package depends upon a native install of
    ;; itself.
-   (self-native-input? #t)
+   (native-inputs (if (%current-target-system)
+                      `(("self" ,this-package))
+                      '()))
 
    (synopsis "File type guesser")
    (description
     "The file command is a file type guesser, a command-line tool that tells
 you in words what kind of data a file contains.  It does not rely on filename
 extensions to tell you the type of a file, but looks at the actual contents
-of the file.")
+of the file.  This package provides the libmagic library.")
    (license bsd-2)
-   (home-page "http://www.darwinsys.com/file/")))
-
+   (home-page "https://www.darwinsys.com/file/")))
