@@ -1,5 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
+;;; Copyright © 2016 Efraim Flashner <efraim@flashner.co.il>
+;;; Copyright © 2018, 2020 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -17,8 +19,7 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages gkrellm)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system gnu)
@@ -30,35 +31,32 @@
 (define-public gkrellm
   (package
     (name "gkrellm")
-    (version "2.3.5")
+    (version "2.3.11")
     (source
      (origin
       (method url-fetch)
-      (uri (string-append "http://members.dslextreme.com/users/billw/gkrellm/gkrellm-"
+      (uri (string-append "http://gkrellm.srcbox.net/releases/gkrellm-"
                           version ".tar.bz2"))
       (sha256
-       (base32
-        "12rc6zaa7kb60b9744lbrlfkxxfniprm6x0mispv63h4kh75navh"))))
+       (base32 "01lccz4fga40isv09j8rjgr0qy10rff9vj042n6gi6gdv4z69q0y"))))
     (build-system gnu-build-system)
     (inputs
-     `(("gettext" ,gnu-gettext)
+     `(("gettext" ,gettext-minimal)
        ("gtk+" ,gtk+-2)
        ("libice" ,libice)
        ("libsm" ,libsm)))
     (native-inputs
      `(("pkg-config" ,pkg-config)))
     (arguments
-     `(#:tests? #f ; there is no check target
+     `(#:tests? #f                      ; there is no check target
        #:phases
-       (alist-delete
-        'configure
-        %standard-phases)
+       (modify-phases %standard-phases
+         (delete 'configure))           ; no configure script
        #:make-flags
        (let ((out (assoc-ref %outputs "out")))
          (list (string-append "INSTALLROOT=" out)
-               "CC=gcc"
-               "X11_LIBS = -lX11 -lSM -lICE -lgmodule-2.0"))))
-    (home-page "http://members.dslextreme.com/users/billw/gkrellm/gkrellm.html")
+               "CC=gcc"))))
+    (home-page "http://gkrellm.srcbox.net/")
     (synopsis "System monitors")
     (description
      "GKrellM is a single process stack of system monitors which supports
