@@ -5,7 +5,8 @@
 ;;; Copyright © 2016 Leo Famulari <leo@famulari.name>
 ;;; Copyright © 2016 Mark H Weaver <mhw@netris.org>
 ;;; Copyright © 2017 Efraim Flashner <efraim@flashner.co.il>
-;;; Copyright © 2018 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2018, 2019 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2018 Alex Vong <alexvong1995@gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -47,17 +48,21 @@
     ;; The 7 release series has an incompatible API, while the 6 series is still
     ;; maintained. Don't update to 7 until we've made sure that the ImageMagick
     ;; users are ready for the 7-series API.
-    (version "6.9.10-3")
+    (version "6.9.11-11")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://imagemagick/ImageMagick-"
                                  version ".tar.xz"))
              (sha256
               (base32
-               "0njq3vp0f3d5992jsah5nhbc5id2bnl7myhdw669k0vmc55mmlcj"))))
+               "1b67rrppvm04aqr76qky5h2a0j2d161h8kwa04fv611w5xwandr2"))))
     (build-system gnu-build-system)
     (arguments
-     `(#:configure-flags '("--with-frozenpaths" "--without-gcc-arch")
+     `(#:configure-flags '("--with-frozenpaths" "--without-gcc-arch"
+
+                           ;; Do not embed the build date in binaries.
+                           "--enable-reproducible-build")
+
        ;; FIXME: The test suite succeeded before version 6.9.6-2.
        ;; Try enabling it again with newer releases.
        #:tests? #f
@@ -100,7 +105,7 @@
               ("libxml2" ,libxml2)
               ("libtiff" ,libtiff)
               ("libpng" ,libpng)
-              ("libjpeg" ,libjpeg)
+              ("libjpeg" ,libjpeg-turbo)
               ("pango" ,pango)
               ("freetype" ,freetype)
               ("bzip2" ,bzip2)
@@ -157,7 +162,7 @@ text, lines, polygons, ellipses and Bézier curves.")
             ;; so skip for now.
             (delete-file "t/mpeg/read.t")
             #t)))))
-    (home-page "http://search.cpan.org/dist/PerlMagick")
+    (home-page "https://metacpan.org/release/PerlMagick")
     (synopsis "Perl interface to ImageMagick")
     (description "This Perl extension allows the reading, manipulation and
 writing of a large number of image file formats using the ImageMagick library.
@@ -169,19 +174,20 @@ script.")
 (define-public graphicsmagick
   (package
     (name "graphicsmagick")
-    (version "1.3.29")
-    (source (origin
-              (method url-fetch)
-              (uri
-                (list
-                  (string-append "mirror://sourceforge/" name "/" name
-                                 "/" version "/GraphicsMagick-" version ".tar.xz")
-                  (string-append "ftp://ftp.graphicsmagick.org/pub/"
-                                 "GraphicsMagick/" (version-major+minor version)
-                                 "/GraphicsMagick-" version ".tar.xz")))
-              (sha256
-               (base32
-                "1m0cc6kpky06lpcipj7rfwc2jbw2igr0jk97zqmw3j1ld5mg93g1"))))
+    (version "1.3.35")
+    (source
+     (origin
+       (method url-fetch)
+       (uri
+        (list
+         (string-append "mirror://sourceforge/graphicsmagick/graphicsmagick"
+                        "/" version "/GraphicsMagick-" version ".tar.xz")
+         (string-append "ftp://ftp.graphicsmagick.org/pub/"
+                        "GraphicsMagick/" (version-major+minor version)
+                        "/GraphicsMagick-" version ".tar.xz")))
+       (sha256
+        (base32
+         "0l024l4hawm9s3jqrgi2j0lxgm61dqh8sgkj1017ma7y11hqv2hq"))))
     (build-system gnu-build-system)
     (arguments
      `(#:configure-flags
@@ -202,7 +208,7 @@ script.")
        ("libxml2" ,libxml2)
        ("libtiff" ,libtiff)
        ("libpng" ,libpng)
-       ("libjpeg" ,libjpeg)
+       ("libjpeg" ,libjpeg-turbo)
        ("freetype" ,freetype)
        ("bzip2" ,bzip2)
        ("xz" ,xz)
