@@ -85,11 +85,10 @@ such as ones for networking and GUI programming.")
     (source
      (origin
        (method url-fetch)
-       (uri (string-append "http://www.squeakvm.org/unix/release/"
+       (uri (string-append "http://squeakvm.org/unix/release/"
                            "Squeak-" version "-src.tar.gz"))
        (sha256
-        (base32
-         "0bpwbnpy2sb4gylchfx50sha70z36bwgdxraym4vrr93l8pd3dix"))
+        (base32 "0bpwbnpy2sb4gylchfx50sha70z36bwgdxraym4vrr93l8pd3dix"))
        (modules '((guix build utils)))
        (snippet
         ;; Make builds bit-reproducible.
@@ -125,23 +124,18 @@ such as ones for networking and GUI programming.")
                             "unix/cmake/squeak.sh.in")
                (("^PATH=.*") ""))
              #t))
-         (add-after 'unpack 'create-build-dir
+         (add-before 'configure 'enter-build-directory
            (lambda _
-             (mkdir "bld")
+             (mkdir "build")
+             (chdir "build")
              #t))
          (replace 'configure
            (lambda* (#:key outputs #:allow-other-keys)
              (let ((out (assoc-ref outputs "out")))
-               (with-directory-excursion "bld"
-                 (invoke "../unix/cmake/configure"
-                           (string-append "--prefix=" out)
-                           "--without-quartz")
-                 #t))))
-         (replace 'build
-           (lambda _
-             (with-directory-excursion "bld"
-               (invoke "make"))
-             #t)))))
+               (invoke "../unix/cmake/configure"
+                       (string-append "--prefix=" out)
+                       "--without-quartz")
+               #t))))))
     (synopsis "Smalltalk programming language and environment")
     (description "Squeak is a full-featured implementation of the Smalltalk
 programming language and environment based on (and largely compatible with)
@@ -149,5 +143,5 @@ the original Smalltalk-80 system.  Squeak has very powerful 2- and 3-D
 graphics, sound, video, MIDI, animation and other multimedia capabilities.  It
 also includes a customisable framework for creating dynamic HTTP servers and
 interactively extensible Web sites.")
-    (home-page "http://www.squeakvm.org")
+    (home-page "http://squeakvm.org/")
     (license license:x11)))
