@@ -1,14 +1,21 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2014, 2015 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2014, 2015, 2017, 2019, 2020 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2013, 2015 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2012, 2013 Nikita Karetnikov <nikita@karetnikov.org>
 ;;; Copyright © 2015 Mark H Weaver <mhw@netris.org>
-;;; Copyright © 2015 Ricardo Wurmus <rekado@elephly.net>
+;;; Copyright © 2015, 2019 Ricardo Wurmus <rekado@elephly.net>
 ;;; Copyright © 2016 Eric Bavier <bavier@member.fsf.org>
 ;;; Copyright © 2016 Leo Famulari <leo@famulari.name>
 ;;; Copyright © 2016 Fabian Harfert <fhmgufs@web.de>
 ;;; Copyright © 2016 Rene Saavedra <rennes@openmailbox.org>
-;;; Copyright © 2016 ng0 <ngillmann@runbox.com>
+;;; Copyright © 2016, 2017 Nikita <nikita@n0.is>
+;;; Copyright © 2017 Clément Lassieur <clement@lassieur.org>
+;;; Copyright © 2017 Petter <petter@mykolab.ch>
+;;; Copyright © 2017 Marius Bakke <mbakke@fastmail.com>
+;;; Copyright © 2017 Arun Isaac <arunisaac@systemreboot.net>
+;;; Copyright © 2017 Rutger Helling <rhelling@mykolab.com>
+;;; Copyright © 2020 André Batista <nandre@riseup.net>
+;;; Copyright © 2020 Helio Machado <0x2b3bfa0+guix@googlemail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -29,19 +36,24 @@
   #:use-module (srfi srfi-9)
   #:export (license? license-name license-uri license-comment
             agpl1 agpl3 agpl3+
+            apsl2
             asl1.1 asl2.0
             boost1.0
             bsd-2 bsd-3 bsd-4
             non-copyleft
-            bsd-style                             ;deprecated!
             cc0
-            cc-by2.0 cc-by3.0 cc-by-sa2.0 cc-by-sa3.0 cc-by-sa4.0
-            cddl1.0
-            cecill-c
+            cc-by2.0 cc-by3.0 cc-by4.0
+            cc-by-sa2.0 cc-by-sa3.0 cc-by-sa4.0
+            cc-sampling-plus-1.0
+            cddl1.0 cddl1.1
+            cecill cecill-b cecill-c
             artistic2.0 clarified-artistic
             copyleft-next
             cpl1.0
+            cua-opl1.0
+            edl1.0
             epl1.0
+            epl2.0
             expat
             freetype
             freebsd-doc
@@ -55,26 +67,42 @@
             ibmpl1.0
             imlib2
             ipa
-            lgpl2.0 lgpl2.0+ lgpl2.1 lgpl2.1+ lgpl3 lgpl3+
+            knuth
+            lgpl2.0 lgpl2.0+ lgpl2.1 lgpl2.1+ lgpl3 lgpl3+ llgpl
+            lppl lppl1.0+ lppl1.1+ lppl1.2 lppl1.2+
+            lppl1.3 lppl1.3+
+            lppl1.3a lppl1.3a+
+            lppl1.3b lppl1.3b+
+            lppl1.3c lppl1.3c+
+            miros
             mpl1.0 mpl1.1 mpl2.0
             ms-pl
             ncsa
-            nmap
+            npsl
+            ogl-psi1.0
             openldap2.8 openssl
+            perl-license
             psfl public-domain
             qpl
+            qwt1.0
             repoze
             ruby
             sgifreeb2.0
             silofl1.1
             sleepycat
             tcl/tk
+            unicode
             unlicense
             vim
+            w3c
             x11 x11-style
             zpl2.1
             zlib
-            fsf-free))
+            fsf-free
+            wtfpl2
+            wxwindows3.1+
+            hpnd
+            fsdg-compatible))
 
 (define-record-type <license>
   (license name uri comment)
@@ -91,6 +119,9 @@
 ;;; https://github.com/NixOS/nixpkgs/blob/master/lib/licenses.nix
 ;;; https://www.gnu.org/licenses/license-list
 ;;;
+;;; Please update spdx-string->license from guix/import/utils.scm
+;;; when modifying this list to avoid mismatches.
+;;;
 ;;; Code:
 
 (define agpl1
@@ -108,6 +139,11 @@
            "https://gnu.org/licenses/agpl.html"
            "https://gnu.org/licenses/why-affero-gpl.html"))
 
+(define apsl2
+  (license "APSL 2.0"
+           "https://directory.fsf.org/wiki/License:APSL-2.0"
+           "https://www.gnu.org/licenses/license-list.html#apsl2"))
+
 (define asl1.1
   (license "ASL 1.1"
            "http://directory.fsf.org/wiki/License:Apache1.1"
@@ -149,12 +185,6 @@ at URI, which may be a file:// URI pointing the package's tree."
             "Check the URI for details.  "
             comment)))
 
-(define bsd-style
-  ;; This alias is kept for backward-compatibility.  Do not use it for new
-  ;; packages: it is ambiguous, as rightfully explained at
-  ;; <http://www.gnu.org/philosophy/words-to-avoid.html#BSD-style>.
-  non-copyleft)
-
 (define cc0
   (license "CC0"
            "http://directory.fsf.org/wiki/License:CC0"
@@ -175,6 +205,11 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://creativecommons.org/licenses/by-sa/2.0/"
            "Creative Commons Attribution-ShareAlike 2.0 Generic"))
 
+(define cc-by4.0
+  (license "CC-BY 4.0"
+           "http://creativecommons.org/licenses/by/4.0/"
+           "Creative Commons Attribution 4.0 Unported"))
+
 (define cc-by3.0
   (license "CC-BY 3.0"
            "http://creativecommons.org/licenses/by/3.0/"
@@ -185,12 +220,35 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://creativecommons.org/licenses/by/2.0/"
            "Creative Commons Attribution 2.0 Generic"))
 
+(define cc-sampling-plus-1.0
+  (license "CC-Sampling+ 1.0"
+           "https://creativecommons.org/licenses/sampling+/1.0"
+           "Creative Commons Sampling Plus 1.0"))
+
 (define cddl1.0
   (license "CDDL 1.0"
            "http://directory.fsf.org/wiki/License:CDDLv1.0"
            "https://www.gnu.org/licenses/license-list#CDDL"))
 
-(define cecill-c
+;; CDDL1.1 is the same as 1.0, except that "Sun Microsystems, Inc" becomes "Oracle",
+;; "LOST PROFITS" becoms "LOSS OF GOODWILL" and a section is added between 6.2
+;; and 6.3.
+(define cddl1.1
+  (license "CDDL 1.1"
+           "https://oss.oracle.com/licenses/CDDL+GPL-1.1"
+           "https://www.gnu.org/licenses/license-list#CDDL"))
+
+(define cecill                                    ;copyleft
+  (license "CeCILL"
+           "http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html"
+           "https://www.gnu.org/licenses/license-list.html#CeCILL"))
+
+(define cecill-b                                  ;non-copyleft
+  (license "CeCILL-B"
+           "http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html"
+           "https://www.gnu.org/licenses/license-list.html#CeCILL"))
+
+(define cecill-c                                  ;weak copyleft
   (license "CeCILL-C"
            "http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html"
            "https://www.gnu.org/licenses/license-list.html#CeCILL"))
@@ -216,11 +274,26 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://directory.fsf.org/wiki/License:CPLv1.0"
            "https://www.gnu.org/licenses/license-list#CommonPublicLicense10"))
 
+(define cua-opl1.0
+  (license "CUA Office Public License v1.0"
+           "https://spdx.org/licenses/CUA-OPL-1.0.html"
+           "https://opensource.org/licenses/CUA-OPL-1.0"))
+
+(define edl1.0
+  (license "EDL 1.0"
+           "http://directory.fsf.org/wiki/License:EDLv1.0"
+           "https://eclipse.org/org/documents/edl-v10.php"))
+
 (define epl1.0
   (license "EPL 1.0"
            "http://directory.fsf.org/wiki/License:EPLv1.0"
            "https://www.gnu.org/licenses/license-list#EPL"))
 
+(define epl2.0
+  (license "EPL 2.0"
+           "https://www.eclipse.org/legal/epl-2.0/"
+           "https://www.gnu.org/licenses/license-list#EPL2"))
+
 (define expat
   (license "Expat"
            "http://directory.fsf.org/wiki/License:Expat"
@@ -233,7 +306,7 @@ at URI, which may be a file:// URI pointing the package's tree."
 
 (define giftware
   (license "Giftware"
-           "http://liballeg.org/license.html"
+           "https://liballeg.org/license.html"
            "The Allegro 4 license"))
 
 (define gpl1
@@ -323,6 +396,11 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://directory.fsf.org/wiki/License:IPA_Font_License"
            "https://www.gnu.org/licenses/license-list#IPAFONT"))
 
+(define knuth
+  (license "Donald Knuth's license for TeX"
+           "http://www.ctan.org/license/knuth"
+           "Modification are only permitted under a different name."))
+
 (define lgpl2.0
   (license "LGPL 2.0"
            "https://www.gnu.org/licenses/old-licenses/lgpl-2.0.html"
@@ -353,6 +431,81 @@ at URI, which may be a file:// URI pointing the package's tree."
            "https://www.gnu.org/licenses/lgpl.html"
            "https://www.gnu.org/licenses/license-list#LGPLv3"))
 
+(define llgpl
+  (license "LLGPL"
+           "https://opensource.franz.com/preamble.html"
+           "Lisp Lesser General Public License"))
+
+(define lppl
+  (license "LPPL (any version)"
+           "https://www.latex-project.org/lppl/lppl-1-0/"
+           "LaTeX Project Public License 1.0"))
+
+(define lppl1.0+
+  (license "LPPL 1.0+"
+           "https://www.latex-project.org/lppl/lppl-1-0/"
+           "LaTeX Project Public License 1.0"))
+
+(define lppl1.1+
+  (license "LPPL 1.1+"
+           "https://www.latex-project.org/lppl/lppl-1-1/"
+           "LaTeX Project Public License 1.1"))
+
+(define lppl1.2
+  (license "LPPL 1.2"
+           "http://directory.fsf.org/wiki/License:LPPLv1.2"
+           "https://www.gnu.org/licenses/license-list#LPPL-1.2"))
+
+(define lppl1.2+
+  (license "LPPL 1.2+"
+           "http://directory.fsf.org/wiki/License:LPPLv1.2"
+           "https://www.gnu.org/licenses/license-list#LPPL-1.2"))
+
+(define lppl1.3
+  (license "LPPL 1.3"
+           "https://www.latex-project.org/lppl/lppl-1-3/"
+           "LaTeX Project Public License 1.3"))
+
+(define lppl1.3+
+  (license "LPPL 1.3+"
+           "https://www.latex-project.org/lppl/lppl-1-3/"
+           "LaTeX Project Public License 1.3+"))
+
+(define lppl1.3a
+  (license "LPPL 1.3a"
+           "http://directory.fsf.org/wiki/License:LPPLv1.3a"
+           "https://www.gnu.org/licenses/license-list#LPPL-1.3a"))
+
+(define lppl1.3a+
+  (license "LPPL 1.3a+"
+           "http://directory.fsf.org/wiki/License:LPPLv1.3a"
+           "https://www.gnu.org/licenses/license-list#LPPL-1.3a"))
+
+(define lppl1.3b
+  (license "LPPL 1.3b"
+           "https://www.latex-project.org/lppl/lppl-1-3b/"
+           "LaTeX Project Public License 1.3b"))
+
+(define lppl1.3b+
+  (license "LPPL 1.3b+"
+           "https://www.latex-project.org/lppl/lppl-1-3b/"
+           "LaTeX Project Public License 1.3b or later"))
+
+(define lppl1.3c
+  (license "LPPL 1.3c"
+           "https://www.latex-project.org/lppl/lppl-1-3c/"
+           "LaTeX Project Public License 1.3c"))
+
+(define lppl1.3c+
+  (license "LPPL 1.3c+"
+           "https://www.latex-project.org/lppl/lppl-1-3c/"
+           "LaTeX Project Public License 1.3c or later"))
+
+(define miros
+  (license "MirOS"
+           "https://www.mirbsd.org/MirOS-Licence.htm"
+           "MirOS License"))
+
 (define mpl1.0
   (license "MPL 1.0"
            "http://www.mozilla.org/MPL/1.0/"
@@ -378,10 +531,15 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://directory.fsf.org/wiki/License:IllinoisNCSA"
            "https://www.gnu.org/licenses/license-list#NCSA"))
 
-(define nmap
-  (license "Nmap license"
-           "https://svn.nmap.org/nmap/COPYING"
-           "https://fedoraproject.org/wiki/Licensing/Nmap"))
+(define npsl
+  (license "Nmap Public Source License"
+           "https://svn.nmap.org/nmap/LICENSE"
+           "https://nmap.org/npsl/"))
+
+(define ogl-psi1.0
+  (license "Open Government Licence for Public Sector Information"
+           "https://www.nationalarchives.gov.uk/doc/open-government-licence/version/1/"
+           #f))
 
 (define openssl
   (license "OpenSSL"
@@ -394,6 +552,12 @@ at URI, which may be a file:// URI pointing the package's tree."
            "https://www.gnu.org/licenses/license-list#newOpenLDAP"))
               ;; lists OpenLDAPv2.7, which is virtually identical
 
+(define perl-license
+  ;; The license of Perl, GPLv1+ or Artistic (we ignore the latter here).
+  ;; We define this alias to avoid circular dependencies introduced by the use
+  ;; of the '(package-license perl)' idiom.
+  gpl1+)
+
 (define psfl
   (license "Python Software Foundation License"
            "http://docs.python.org/license.html"
@@ -409,6 +573,11 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://directory.fsf.org/wiki/License:QPLv1.0"
            "http://www.gnu.org/licenses/license-list.html#QPL"))
 
+(define qwt1.0
+  (license "QWT 1.0"
+           "http://qwt.sourceforge.net/qwtlicense.html"
+           "GNU Lesser General Public License with exceptions"))
+
 (define repoze
   (license "Repoze"
            "http://repoze.org/LICENSE.txt"
@@ -445,11 +614,31 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://directory.fsf.org/wiki/License:Vim7.2"
            "http://www.gnu.org/licenses/license-list.html#Vim"))
 
+(define unicode
+  (license "Unicode"
+           "https://directory.fsf.org/wiki/License:Unicode"
+           "http://www.gnu.org/licenses/license-list.html#Unicode"))
+
 (define unlicense
   (license "Unlicense"
            "https://unlicense.org/"
            "https://www.gnu.org/licenses/license-list.html#Unlicense"))
 
+(define w3c
+  (license "W3C Software Notice and License"
+           "https://directory.fsf.org/wiki/License:W3C_31Dec2002"
+           "https://www.gnu.org/licenses/license-list.en.html#W3C"))
+
+(define wtfpl2
+  (license "WTFPL 2"
+           "http://www.wtfpl.net"
+           "http://www.wtfpl.net/about/"))
+
+(define wxwindows3.1+
+  (license "wxWindows 3.1+"
+           "https://wxwidgets.org/about/licence"
+           "https://www.gnu.org/licenses/license-list.html#Wxwind"))
+
 (define x11
   (license "X11"
            "http://directory.fsf.org/wiki/License:X11"
@@ -472,9 +661,14 @@ which may be a file:// URI pointing the package's tree."
 
 (define zlib
   (license "Zlib"
-           "http://www.gzip.org/zlib/zlib_license.html"
+           "https://zlib.net/zlib_license.html"
            "https://www.gnu.org/licenses/license-list#ZLib"))
 
+(define hpnd
+  (license "HPND"
+           "https://directory.fsf.org/wiki/License:HPND"
+           "https://www.gnu.org/licenses/license-list#HPND"))
+
 (define* (fsf-free uri #:optional (comment ""))
   "Return a license that does not fit any of the ones above or a collection
 of licenses, approved as free by the FSF.  More details can be found at URI."
@@ -482,4 +676,13 @@ of licenses, approved as free by the FSF.  More details can be found at URI."
            uri
            comment))
 
+(define* (fsdg-compatible uri #:optional (comment ""))
+  "Return a license that does not fit any of the ones above or a collection
+of licenses, not necessarily free, but in accordance with FSDG as Non-functional
+Data.  More details can be found at URI.  See also
+https://www.gnu.org/distros/free-system-distribution-guidelines.en.html#non-functional-data."
+  (license "FSDG-compatible"
+           uri
+           comment))
+
 ;;; licenses.scm ends here
