@@ -190,7 +190,7 @@ Return the coverage ratio, an exact number between 0 and 1."
                                  narinfos))
           (time      (+ (time-second time)
                         (/ (time-nanosecond time) 1e9))))
-      (format #t (G_ "  ~2,1f% substitutes available (~h out of ~h)~%")
+      (format #t (G_ "  ~,1f% substitutes available (~h out of ~h)~%")
               (* 100. (/ obtained requested 1.))
               obtained requested)
       (let ((total (/ (reduce + 0 sizes) MiB)))
@@ -495,7 +495,9 @@ SERVER.  Display information for packages with at least THRESHOLD dependents."
 ;;; Entry point.
 ;;;
 
-(define (guix-weather . args)
+(define-command (guix-weather . args)
+  (synopsis "report on the availability of pre-built package binaries")
+
   (define (package-list opts)
     ;; Return the package list specified by OPTS.
     (let ((files (filter-map (match-lambda
